// Mugurel Ionut Andreica
// O(N * log(N) + nr_laturi_convex_hull^2 * (N + K))

#include <stdio.h>
#include <vector>
#include <algorithm>

using namespace std;

#define NMAX 333

#define min(a,b) ((a) <= (b) ? (a) : (b))
#define max(a,b) ((a) >= (b) ? (a) : (b))

vector<pair<double, double> > p;
double astk[NMAX], bstk[NMAX], cstk[NMAX], a, b;
int stk[NMAX];
int i, j, q, r, N, K, niv;

int semn(int i, int j, int k) {
	double a, b, c, r;
	a = p[i].first - p[j].first;
	b = p[j].second - p[i].second;
	c = -(a * p[i].second + b * p[i].first);
	r = a * p[k].second + b * p[k].first + c;
	if (r > 0)
		return +1;
	if (r < 0)
		return -1;
	return 0;
}

void convex_hull() {
	stk[0] = 0;
	stk[niv = 1] = 1;
	for (i = 2; i < p.size(); i++) {
		while (niv >= 1 && semn(stk[niv - 1], stk[niv], i) < 0)
			niv--;
		niv++;
		stk[niv] = i;
	}
	
	fprintf(stderr, "convex hull:\n");
	for (i = niv; i >= 0; i--)
		fprintf(stderr, "%d: x=%.4lf, y=%.4lf\n", i, p[stk[i]].second, p[stk[i]].first);
	
	for (i = 1; i <= niv; i++) {
		astk[i] = p[stk[i - 1]].first - p[stk[i]].first;
		bstk[i] = p[stk[i]].second - p[stk[i - 1]].second;
		cstk[i] = -(astk[i] * p[stk[i]].second + bstk[i] * p[stk[i]].first);
	}
}

#define INF 1e9

double dmin[NMAX][NMAX], memo_dsum[NMAX][NMAX];

void dp() {
	dmin[0][0] = 0.0;
	for (j = 1; j <= K; j++)
		dmin[0][j] = INF;
	
	for (i = 1; i <= niv; i++)
		for (j = 0; j < i; j++)
			memo_dsum[i][j] = -1.0;

	for (i = 1; i <= niv; i++) {
		// (stk[i-1],stk[i]) e latura curenta de pe convex hull. 
		dmin[i][0] = INF;
		for (j = 1; j <= K; j++) {
			dmin[i][j] = INF;
			if ((j == K && p[stk[i]].second >= p[stk[i - 1]].second) || (j > i)) {
				// Daca muchia i nu e orientata inspre OY, atunci nu poate fi
				// selectata ca ultima muchie a poligonului.
				// Daca j > i, atunci nu putem avea j laturi pana la latura i.
				continue;
			}

			// Alege latura anterioara de pe convex hull (stk[q-1],stk[q]).
			for (q = i - 1; q >= 0; q--) {
				double s = 0.0;
				if (memo_dsum[i][q] < 0.0) {
					for (r = stk[q] + 1; r < stk[i]; r++) {
						double xdq, xdi;
						if (q == 0)
							xdq = INF;
						else
							xdq = -(bstk[q] * p[r].first + cstk[q]) / astk[q];
						xdi = -(bstk[i] * p[r].first + cstk[i]) / astk[i];
						s += min(xdi, xdq) - p[r].second;
					}
					memo_dsum[i][q] = s;
				} else
					s = memo_dsum[i][q];
				
				s += dmin[q][j - 1];
				dmin[i][j] = min(dmin[i][j], s);
			}
		}
	}

	// Adauga distantele punctelor aflate peste a K-a sau a (K-1)-a latura selectata.
	for (i = 0; i <= niv; i++) {
		double xmax = 0.0;
		for (r = stk[i] + 1; r < p.size(); r++)
			xmax = max(xmax, p[r].second);

		double sk = 0.0, skm1 = 0.0;
		for (r = stk[i] + 1; r < p.size(); r++) {
			double x;
			if (i > 0)
				x = -(bstk[i] * p[r].first + cstk[i]) / astk[i];
			else
				x = INF;
			sk += x - p[r].second;
			skm1 += min(x, xmax) - p[r].second;
		}
		dmin[i][K] += sk;
		dmin[i][K - 1] += skm1;
	}

	for (a = b = INF, i = 0; i <= niv; i++) {
		a = min(a, dmin[i][K]);
		b = min(b, dmin[i][K - 1]);
	}

	fprintf(stderr, "best with K=%d edges from the convex hull=%.3lf\nbest with K-1=%d edges from the convex hull plus 1 extra closing \"vertical\" edge=%.3lf\n", K, a, K - 1, b);
}

int main() {
	freopen("insula.in", "r", stdin);
	freopen("insula.out", "w", stdout);
	scanf("%d %d", &N, &K);
	for (i = 1; i <= N; i++) {
		scanf("%lf %lf", &a, &b);
		p.push_back(make_pair(b, a));
	}

	p.push_back(make_pair(0, 0));
	sort(p.begin(), p.end());
	convex_hull();
	
	fprintf(stderr, "number of convex hull edges=%d\n", niv);
	if (K > niv) {
		K = niv + 1;
		fprintf(stderr, "resetting K to %d\n", K);
	}

	dp();

	printf("%.4lf\n", min(a, b));
	
	return 0;
}
