// Insula - O (N * H ^ 2 + K * H ^ 2) - 95 puncte
#include <cstdio>
#include <algorithm>
using namespace std;

#define NMAX 310
#define MAX 2000000
#define INF 0x3f3f3f3f

struct point {
	double x, y;
	int convex;
} P[NMAX];

int N, K, size, H;
int stack[NMAX], viz[NMAX], ch[NMAX];

double dp[NMAX][NMAX], dist[NMAX][NMAX];

bool determ (long long x1, long long y1, long long x2, long long y2, long long x3, long long y3) {

	return ((x2 - x1) * (y3 - y1) - (x3 - x1) * (y2 - y1) ) <= 0;
}

bool cmpX (const point &a,const point &b) {

	if (a.x == b.x)	return a.y < b.y;
	return a.x < b.x;
}

bool cmpY (const point &a,const point &b) {

	if (a.y == b.y)	return a.x < b.x;
	return a.y < b.y;
}

void convexHull () {

	int i, step = 1;

	stack[++size] = 1;
	stack[++size] = 2;
	viz[2] = 1; i = 2; step = 1;

	while (!viz[1]) {

		if (i == N) break;
		i+= step;

		while (viz[i]) {
			if (i == N) step = -1;
			i+= step;
		}

		while (size > 1 && !determ (P[stack[size]].x, P[stack[size]].y, P[stack[size-1]].x, P[stack[size-1]].y, P[i].x, P[i].y))
			viz[stack[size--]] = 0;

		viz[i] = 1;
		stack[++size] = i;
	}

	for (int i = 1; i <= size; i++)
		P[stack[i]].convex = 1;
}

double distance (double x, double y, double x1, double y1, double x2, double y2) {

	if (y2 - y1 == 0) {
		if (y == y1) return min (x1, x2) - x;
		return INF;
	}

    return (y - y1) * (x2 - x1) / (y2 - y1) + x1 - x;
}

void solve () {

	int i, j, l;

	P[++N].x = 0; P[N].y = 0;
	sort (P + 1, P + N + 1, cmpY); convexHull();
	sort (P + 1, P + N + 1, cmpY);

	for (i = 1; i <= N; i++)
		if (P[i].convex && (H == 0 || P[i].y >= P[ch[H]].y))
			ch[++H] = i;

	double sol = INF, curr;

	ch[H + 1] = ch[H];
	for (i = 2; i <= H + 1; i++) {
		for (j = i-1; j >= 1; j--) {
			for (l = ch[j] + 1; l <= ch[i]; l++) {
				curr = INF;
				if (j != 1) curr = distance (P[l].x,P[l].y,P[ch[j]].x,P[ch[j]].y,P[ch[j-1]].x,P[ch[j-1]].y);

				if (i == 6 && j == 1)
                    int bla = 0;

				if (i != H+1)
					curr = min (curr, distance (P[l].x, P[l].y, P[ch[i]].x, P[ch[i]].y, P[ch[i-1]].x, P[ch[i-1]].y));
				dist[i][j]+= curr;
			}
		}

		dp[1][i] = dist[i][1];
	}

	dp[1][1] = INF;
	K = min (K, H-1);
	for (i = 2; i <= K; i++) {
		dp[i][i] = INF;
		for (j = i + 1; j <= H; j++) {
			dp[i][j] = INF;
			for (l = j - 1; l >= i; l--)
				dp[i][j] = min (dp[i][j], dp[i-1][l] + dist[j][l]);

			if (i == K && P[ ch[j] ].x < P[ ch[j-1] ].x)
				sol = min (sol, dp[K][j] + dist[H+1][j]);
		}
	}
    
	int pmax=0, xmax= 0;
	
	for (i = 1; i <= H; i++) {
		if (P[ ch[i] ].x > xmax) {
			xmax = P[ch[i]].x;
			pmax = i;			 
		}    
	}

	double add = 0;
	for (j = 1; j <= N; j++)
		if (P[ j ].y > P[ ch[pmax] ].y)
			add+= P[ ch[pmax] ].x - P[j].x;
	curr = 0;
    if (pmax >= K) {
		for (i = 2; i < pmax; i++) {
			curr = dp[K-1][i] + add;
			for (j = 1; j <= N; j++) {
				if (P[j].y > P[ ch[i] ].y && P[j].y <= P[ ch[pmax] ].y) {
						curr+= min ( distance (P[j].x, P[j].y, P[ch[i]].x, P[ch[i]].y, P[ch[i-1]].x, P[ch[i-1]].y), P[ch[pmax]].x - P[j].x);
				}
			}
            sol = min (sol, curr);
		}                     
	}

	printf ("%lf\n", min (sol, dp[K-1][H]));
}

void readData () {

	scanf ("%d %d", &N, &K);
	for (int i = 1; i <= N; i++)
		scanf ("%lf %lf", &P[i].x, &P[i].y);
}

int main () {

    freopen ("insula.in", "r", stdin);
    freopen ("insula.out", "w", stdout);

	readData ();
	solve ();

	return 0;
}

