// Mugurel Ionut Andreica
// O(log(N) + BMAX) per query

#include <stdio.h>
#include <set>

using namespace std;

#define BMAX 64

set<pair<long long, long long> > free_mem;
long long bit[BMAX], N;

void compute_bits() {
	bit[0] = 1;
	for (int i = 1; i < BMAX; i++)
		bit[i] = bit[i - 1] << 1;
}

void read_input() {
	long long li, ls, start = 0;
	int P;
	scanf("%lld %d", &N, &P);
	for (int i = 1; i <= P + 1; i++) {
		if (i <= P)
			scanf("%lld %lld", &li, &ls);
		else
			li = ls = N;

		if (li > start) {
			long long len = li - start;
			for (int i = 0; i < BMAX; i++)
				if ((len & bit[i]) > 0) {
					free_mem.insert(make_pair(bit[i], start));
//					fprintf(stderr, "start=%lld : len=%lld\n", start, bit[i]);
					start += bit[i];
				}
		}
		start = ls + 1;
	}
}

long long get_address(long long size) {
	set<pair<long long, long long> >::iterator mem_zone = free_mem.lower_bound(make_pair(size, -1));
	if (mem_zone == free_mem.end()) {
		return -1;
	}
	long long len = mem_zone->first, start = mem_zone->second;
	free_mem.erase(*mem_zone);
	
	len -= size;
	if (len > 0) {
		for (int i = 0; i < BMAX; i++)
			if ((len & bit[i]) > 0) {
				free_mem.insert(make_pair(bit[i], start));
				start += bit[i];
			}
	}
	
	return start;
}

void process_queries() {
	int b;
	long long size, address;
	while (1) {
		scanf("%d", &b);
		if (b < 0)
			break;
		size = bit[b];
		address = get_address(size);
		printf("%lld\n", address);
		fflush(stdout);
	}
}

int main() {
	compute_bits();
	read_input();
	process_queries();
	return 0;
}
